@@ -220,15 +220,15 @@ def correct_C80_success_code(df):
     # C80 has an special conversion Status, setting it to 14 like the other campaigns
 
     # Correcting non perfect conversions
-    df.loc[(df['idCampaign'] == '80') &
+    df.loc[(df['idCampaign'] == 80) &
            (df['BV'].notna()), 'IDEmailStatus'] == 2
-    aux = df.loc[(df['idCampaign'] == '80') &
+    aux = df.loc[(df['idCampaign'] == 80) &
                  (df['IDEmailStatus'] == 31)].shape
     logger.info(f'C80 successes: {aux}')
-    df.loc[(df['idCampaign'] == '80') &
+    df.loc[(df['idCampaign'] == 80) &
            (df['IDEmailStatus'] == 31),
            'IDEmailStatus'] = 14
-    aux = df.loc[(df['idCampaign'] == '80') &
+    aux = df.loc[(df['idCampaign'] == 80) &
                  (df['IDEmailStatus'] == 14)].shape
     logger.info(f'C80 successes: {aux}')
 
